import { ValidationError } from 'class-validator';
import { AllowPrimitives } from '../../../../types';
/**
* Document identification
*/
export interface iRDocumentIdentification {
    /**
    * Page index
    * @type {number}
    */
    pageIndex: number;
    /**
    * Document name
    * @type {string}
    */
    documentName: string;
    /**
    * Is deprecated
    * @type {boolean}
    */
    isDeprecated: boolean;
    /**
    * Probability
    * @type {number}
    */
    probability: number;
    /**
    * Document id
    * @type {number}
    */
    documentId: number;
    /**
    * Document category
    * @type {string|undefined}
    */
    documentCategory?: string;
}
/**
* Document identification
*/
export declare class RDocumentIdentification implements iRDocumentIdentification {
    /**
    * Page index
    * @type {number}
    */
    pageIndex: number;
    /**
    * Document name
    * @type {string}
    */
    documentName: string;
    /**
    * Is deprecated
    * @type {boolean}
    */
    isDeprecated: boolean;
    /**
    * Probability
    * @type {number}
    */
    probability: number;
    /**
    * Document id
    * @type {number}
    */
    documentId: number;
    /**
    * Document category
    * @type {string|undefined}
    */
    documentCategory?: string;
    /**
    * Create RDocumentIdentification from plain object
    * @param {AllowPrimitives<iRDocumentIdentification>} input
    * @returns {RDocumentIdentification}
    */
    static fromPlain: (input: AllowPrimitives<iRDocumentIdentification>) => RDocumentIdentification;
    /**
    * Get validation errors
    * @param {RDocumentIdentification} input
    * @returns {ValidationError[]}
    */
    static getValidationErrors: (input: RDocumentIdentification) => ValidationError[];
    /**
    * Check if input is valid
    * @param {RDocumentIdentification | RDocumentIdentification[]} input - An RDocumentIdentification or array of RDocumentIdentification to check for validity
    * @returns {boolean}
    */
    static isValid: (input: RDocumentIdentification | RDocumentIdentification[]) => boolean;
}
